@@ -23,17 +23,37 @@ netcdf = NetCDFWrite(implementation())
 
 
 @_manage_log_level_via_verbosity
-def write(fields, filename, fmt='NETCDF4', overwrite=True,
-          global_attributes=None, file_descriptors=None,
-          external=None, Conventions=None, datatype=None,
-          least_significant_digit=None, endian='native', compress=0,
-          fletcher32=False, shuffle=True, reference_datetime=None,
-          verbose=None, cfa_options=None, mode='w', single=None,
-          double=None, variable_attributes=None, string=True,
-          warn_valid=True, group=True, coordinates=False,
-          HDF_chunksizes=None, no_shuffle=None, unlimited=None):
-    '''Write field constructs to a netCDF file.
-
+def write(
+    fields,
+    filename,
+    fmt="NETCDF4",
+    mode="w",
+    overwrite=True,
+    global_attributes=None,
+    file_descriptors=None,
+    external=None,
+    Conventions=None,
+    datatype=None,
+    least_significant_digit=None,
+    endian="native",
+    compress=0,
+    fletcher32=False,
+    shuffle=True,
+    reference_datetime=None,
+    verbose=None,
+    cfa_options=None,
+    single=None,
+    double=None,
+    variable_attributes=None,
+    string=True,
+    warn_valid=True,
+    group=True,
+    coordinates=False,
+    HDF_chunksizes=None,
+    no_shuffle=None,
+    unlimited=None,
+):
+    """Write field constructs to a netCDF file.
 
     **File format**
 
@@ -176,6 +196,61 @@ def write(fields, filename, fmt='NETCDF4', overwrite=True,
             ``'NETCDF4'`` files use the version 4 disk format (HDF5)
             and use the new features of the version 4 API.
 
+        mode: `str`, optional
+            Specify the mode of write access for the output file. One of:
+
+            ========  =================================================
+            *mode*    Description
+            ========  =================================================
+            ``'w'``   Open a new file for writing to. If it exists and
+                      *overwrite* is True then the file is deleted
+                      prior to being recreated.
+
+            ``'a'``   Open an existing file for appending new
+                      information to. The new information will be
+                      incorporated whilst the original contents of the
+                      file will be preserved.
+
+                      In practice this means that new fields will be
+                      created, whilst the original fields will not be
+                      edited at all. Coordinates on the fields, where
+                      equal, will be shared as standard.
+
+                      For append mode, note the following:
+
+                      * Global attributes on the file
+                        will remain the same as they were originally,
+                        so will become inaccurate where appended fields
+                        have incompatible attributes. To rectify this,
+                        manually inspect and edit them as appropriate
+                        after the append operation using methods such as
+                        `nc_clear_global_attributes` and
+                        `nc_set_global_attribute`.
+
+                      * Fields with incompatible ``featureType`` to
+                        the original file cannot be appended.
+
+                      * At present fields with groups cannot be
+                        appended, but this will be possible in a future
+                        version. Groups can however be cleared, the
+                        fields appended, and groups re-applied, via
+                        methods such as `nc_clear_variable_groups` and
+                        `nc_set_variable_groups`, to achieve the same
+                        for now.
+
+                      * At present domain ancillary constructs of
+                        appended fields may not be handled correctly
+                        and can appear as extra fields. Set them on the
+                        resultant fields using `set_domain_ancillary`
+                        and similar methods if required.
+
+            ``'r+'``  Alias for ``'a'``.
+
+            ========  =================================================
+
+            By default the file is opened with write access mode
+            ``'w'``.
+
         overwrite: `bool`, optional
             If False then raise an error if the output file
             pre-exists. By default a pre-existing output file is
@@ -294,20 +369,6 @@ def write(fields, filename, fmt='NETCDF4', overwrite=True,
             external to the named external file. Ignored if there are
             no such constructs.
 
-        mode: `str`, optional
-            Specify the mode of write access for the output file. One of:
-
-            =======  =================================================
-            *mode*   Description
-            =======  =================================================
-            ``'w'``  Open a new file for writing to. If it exists and
-                     *overwrite* is True then the file is deleted
-                     prior to being recreated.
-            =======  =================================================
-
-            By default the file is opened with write access mode
-            ``'w'``.
-
         cfa_options: `dict`, optional
             A dictionary giving parameters for configuring the output
             CFA-netCDF file:
@@ -512,8 +573,8 @@ def write(fields, filename, fmt='NETCDF4', overwrite=True,
             If False then create a "flat" netCDF file, i.e. one with
             only the root group, regardless of any group structure
             specified by the field constructs. By default any groups
-            defined by the netCDF interface of the field constucts and
-            its components will be created and populated.
+            defined by the netCDF interface of the field constructs
+            and its components will be created and populated.
 
             .. versionadded:: 3.6.0
 
@@ -552,24 +613,27 @@ def write(fields, filename, fmt='NETCDF4', overwrite=True,
 
     >>> cf.write(f, 'file.nc', Conventions='CMIP-6.2')
 
-    '''
+    """
     if unlimited is not None:
         _DEPRECATION_ERROR_FUNCTION_KWARGS(
-            'cf.write', {'unlimited': unlimited},
-            "Use method 'DomainAxis.nc_set_unlimited' instead."
+            "cf.write",
+            {"unlimited": unlimited},
+            "Use method 'DomainAxis.nc_set_unlimited' instead.",
         )  # pragma: no cover
 
     if no_shuffle is not None:
         _DEPRECATION_ERROR_FUNCTION_KWARGS(
-            'cf.write', {'no_shuffle': no_shuffle},
-            "Use keyword 'shuffle' instead."
+            "cf.write",
+            {"no_shuffle": no_shuffle},
+            "Use keyword 'shuffle' instead.",
         )  # pragma: no cover
 
     if HDF_chunksizes is not None:
         _DEPRECATION_ERROR_FUNCTION_KWARGS(
-            'cf.write', {'HDF_chunksizes': HDF_chunksizes},
+            "cf.write",
+            {"HDF_chunksizes": HDF_chunksizes},
             "HDF chunk sizes may be set for individual field constructs "
-            "prior to writing, instead."
+            "prior to writing, instead.",
         )  # pragma: no cover
 
     # Flatten the sequence of intput fields
@@ -606,8 +670,9 @@ def write(fields, filename, fmt='NETCDF4', overwrite=True,
         # --- End: if
 
         if single is not None and double is not None:
-            raise ValueError("Can't set both the single and double "
-                             "parameters")
+            raise ValueError(
+                "Can't set both the single and double " "parameters"
+            )
 
         if single is not None and not single:
             double = True
@@ -616,55 +681,70 @@ def write(fields, filename, fmt='NETCDF4', overwrite=True,
             single = True
 
         if single:
-            datatype = {numpy.dtype(float): numpy.dtype('float32'),
-                        numpy.dtype(int): numpy.dtype('int32')}
+            datatype = {
+                numpy.dtype(float): numpy.dtype("float32"),
+                numpy.dtype(int): numpy.dtype("int32"),
+            }
 
         if double:
-            datatype = {numpy.dtype('float32'): numpy.dtype(float),
-                        numpy.dtype('int32'): numpy.dtype(int)}
+            datatype = {
+                numpy.dtype("float32"): numpy.dtype(float),
+                numpy.dtype("int32"): numpy.dtype(int),
+            }
 
         extra_write_vars = {
-            'cfa': False,
-            'cfa_options': {},
-            'reference_datetime': reference_datetime,
+            "cfa": False,
+            "cfa_options": {},
+            "reference_datetime": reference_datetime,
         }
 
         # CFA options
-        if fmt in ('CFA', 'CFA4'):
-            extra_write_vars['cfa'] = True
-            fmt = 'NETCDF4'
+        if fmt in ("CFA", "CFA4"):
+            extra_write_vars["cfa"] = True
+            fmt = "NETCDF4"
             if cfa_options:
-                extra_write_vars['cfa_options'] = cfa_options
-        elif fmt == 'CFA3':
-            extra_write_vars['cfa'] = True
-            fmt = 'NETCDF3_CLASSIC'
+                extra_write_vars["cfa_options"] = cfa_options
+        elif fmt == "CFA3":
+            extra_write_vars["cfa"] = True
+            fmt = "NETCDF3_CLASSIC"
             if cfa_options:
-                extra_write_vars['cfa_options'] = cfa_options
+                extra_write_vars["cfa_options"] = cfa_options
         # --- End: if
 
-        if extra_write_vars['cfa']:
+        if extra_write_vars["cfa"]:
             if Conventions:
                 if isinstance(Conventions, str):
                     Conventions = (Conventions,)
 
-                Conventions = tuple(Conventions) + ('CFA',)
+                Conventions = tuple(Conventions) + ("CFA",)
             else:
-                Conventions = 'CFA'
+                Conventions = "CFA"
         # --- End: if
 
-        netcdf.write(fields, filename, fmt=fmt, overwrite=overwrite,
-                     global_attributes=global_attributes,
-                     variable_attributes=variable_attributes,
-                     file_descriptors=file_descriptors,
-                     external=external, Conventions=Conventions,
-                     datatype=datatype,
-                     least_significant_digit=least_significant_digit,
-                     endian=endian, compress=compress,
-                     shuffle=shuffle, fletcher32=fletcher32,
-                     verbose=verbose, string=string,
-                     warn_valid=warn_valid, group=group,
-                     coordinates=coordinates,
-                     extra_write_vars=extra_write_vars)
+        netcdf.write(
+            fields,
+            filename,
+            fmt=fmt,
+            mode=mode,
+            overwrite=overwrite,
+            global_attributes=global_attributes,
+            variable_attributes=variable_attributes,
+            file_descriptors=file_descriptors,
+            external=external,
+            Conventions=Conventions,
+            datatype=datatype,
+            least_significant_digit=least_significant_digit,
+            endian=endian,
+            compress=compress,
+            shuffle=shuffle,
+            fletcher32=fletcher32,
+            verbose=verbose,
+            string=string,
+            warn_valid=warn_valid,
+            group=group,
+            coordinates=coordinates,
+            extra_write_vars=extra_write_vars,
+        )
     # --- End: if
 
     if mpi_on and write_only_on_pe0:
